@@ -279,6 +279,19 @@ setReplaceMethod("header", c("VCF", "VCFHeader"),
     x
 })
 
+## vcfFields
+setMethod("vcfFields", "missing",
+    function(x, ...)
+{
+    vcfFields(VCFHeader())
+})
+
+setMethod("vcfFields", "VCF",
+    function(x, ...)
+{
+    vcfFields(header(x))
+})
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Subsetting and combining
 ###
