@@ -1,10 +1,10 @@
 ### =========================================================================
-### VRangesList: Where there is a Ranges, there must be a List
+### VRangesList: Where there is an IntegerRanges, there must be a List
 ### -------------------------------------------------------------------------
 ###
 
 VRangesList <- function(...) {
-  new("SimpleVRangesList", GenomicRangesList(...))
+  new("SimpleVRangesList", GenomicRangesList(...), elementType="VRanges")
 }
 
 setMethod("stackSamples", "VRangesList", function(x) {
