@@ -100,3 +100,23 @@ setMethod("seqinfo", "VcfFileList",
     grl <- as(si, "GRangesList")
     seqinfo(grl)
 })
+
+setMethod("vcfFields", "character",
+    function(x, ...)
+{
+    stopifnot(!is.na(x), all(file.exists(x)))
+    hdr <- scanVcfHeader(x)
+    vcfFields(hdr)
+})
+
+setMethod("vcfFields", "VcfFile",
+          function(x, ...)
+{
+    vcfFields(path(x))
+})
+
+setMethod("vcfFields", "VcfFileList",
+    function(x, ...)
+{
+    vcfFields(path(x))
+})
